summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetecontactlistelement.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetecontactlistelement.h')
-rw-r--r--kopete/libkopete/kopetecontactlistelement.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/kopete/libkopete/kopetecontactlistelement.h b/kopete/libkopete/kopetecontactlistelement.h
index b0f2eb69..6e9d1816 100644
--- a/kopete/libkopete/kopetecontactlistelement.h
+++ b/kopete/libkopete/kopetecontactlistelement.h
@@ -19,8 +19,8 @@
#ifndef KOPETEPLUGINDATAOBJECT_H
#define KOPETEPLUGINDATAOBJECT_H
-#include <qobject.h>
-#include <qdom.h>
+#include <tqobject.h>
+#include <tqdom.h>
#include "kopete_export.h"
@@ -41,12 +41,12 @@ class Plugin;
*
* It also allow to store an icon for this element.
*/
-class KOPETE_EXPORT ContactListElement : public QObject /* public KopeteNotifyDataObject */
+class KOPETE_EXPORT ContactListElement : public TQObject /* public KopeteNotifyDataObject */
{
Q_OBJECT
protected:
- ContactListElement( QObject *parent = 0L, const char *name = 0L );
+ ContactListElement( TQObject *parent = 0L, const char *name = 0L );
~ContactListElement();
@@ -54,7 +54,7 @@ public:
/**
* Set the plugin-specific data.
* The data in the provided QMap is a set of key/value pairs.
* Note that protocol plugins usually shouldn't use this method, but
* reimplement @ref Contact::serialize() instead. This method
* is called by @ref Protocol for those classes.
@@ -63,7 +63,7 @@ public:
* You may want to consider the @ref setPluginData() overload
* that takes a single field as parameter.
*/
- void setPluginData( Plugin *plugin, const QMap<QString, QString> &value );
+ void setPluginData( Plugin *plugin, const TQMap<TQString, TQString> &value );
/**
* Convenience method to store or change only a single field of the
@@ -73,7 +73,7 @@ public:
*
* Note that you should save the file after adding data or it will get lost.
*/
- void setPluginData( Plugin *plugin, const QString &key, const QString &value );
+ void setPluginData( Plugin *plugin, const TQString &key, const TQString &value );
/**
* Get the settings as stored previously by calls to @ref setPluginData()
@@ -81,7 +81,7 @@ public:
* Note that calling this method for protocol plugins that use the
* @ref Contact::serialize() API may yield unexpected results.
*/
- QMap<QString, QString> pluginData( Plugin *plugin ) const;
+ TQMap<TQString, TQString> pluginData( Plugin *plugin ) const;
/**
* Convenience method to retrieve only a single field from the plugin
@@ -91,7 +91,7 @@ public:
* from the XML file. Don't call this method before then (e.g. in
* constructors).
*/
- QString pluginData( Plugin *plugin, const QString &key ) const;
+ TQString pluginData( Plugin *plugin, const TQString &key ) const;
/**
* The various icon states. Some state are reserved for Groups,
@@ -105,13 +105,13 @@ public:
* if there is no icon registered for this state, the None icon is used
* if available
*/
- QString icon( IconState state = None ) const;
+ TQString icon( IconState state = None ) const;
/**
* Set the icon in the given state
* To clear an entry, set a QString::null
*/
- void setIcon( const QString &icon, IconState = None );
+ void setIcon( const TQString &icon, IconState = None );
/**
* return if yes or no the user wants to display some custom icon.
@@ -134,7 +134,7 @@ signals:
/**
* The icon to use for some state has changed
*/
- void iconChanged( Kopete::ContactListElement::IconState, const QString & );
+ void iconChanged( Kopete::ContactListElement::IconState, const TQString & );
/**
* The visual appearance of some of our icons has changed
@@ -150,14 +150,14 @@ protected:
/**
* Return a XML representation of plugin data
*/
- const QValueList<QDomElement> toXML();
+ const TQValueList<TQDomElement> toXML();
/**
* Load plugin data from one Dom Element:
* It should be a <plugin-data> element or a <custom-icons> element. if not, nothing will happen
* @return true if something has ben loaded. false if the element was not a fine
*/
- bool fromXML( const QDomElement &element );
+ bool fromXML( const TQDomElement &element );
private:
class Private;
@@ -54,7 +54,7 @@ public:
/**
* Set the plugin-specific data.
- * The data in the provided QMap is a set of key/value pairs.
+ * The data in the provided TQMap is a set of key/value pairs.
* Note that protocol plugins usually shouldn't use this method, but
* reimplement @ref Contact::serialize() instead. This method
@@ -105,13 +105,13 @@ public:
/**
* Set the icon in the given state
- * To clear an entry, set a QString::null
+ * To clear an entry, set a TQString::null
*/